[slime-cvs] CVS update: slime/slime.el

Dan Barlow dbarlow at common-lisp.net
Mon Oct 20 13:56:36 UTC 2003


Update of /project/slime/cvsroot/slime
In directory common-lisp.net:/tmp/cvs-serv7288

Modified Files:
	slime.el 
Log Message:

Date: Mon Oct 20 09:56:36 2003
Author: dbarlow

Index: slime/slime.el
diff -u slime/slime.el:1.46 slime/slime.el:1.47
--- slime/slime.el:1.46	Sun Oct 19 17:36:21 2003
+++ slime/slime.el	Mon Oct 20 09:56:36 2003
@@ -375,7 +375,7 @@
 	(= emacs-major-version 20))
     ;; XEmacs truncates multi-line messages in the echo area.
     (defun slime-message (fmt &rest args)
-      (slime-display-message-or-view (apply #'format fmt args) "*CMUCL Note*"))
+      (slime-display-message-or-view (apply #'format fmt args) "*SLIME Note*"))
   (defun slime-message (fmt &rest args)
     (apply 'message fmt args)))
 
@@ -476,7 +476,7 @@
 		     nil nil initial-value)))
 
 
 ;;; CMUCL Setup: compiling and connecting to Swank
 
 (defvar slime-connect-retry-timer nil
   "Timer object for connection retries.")
@@ -577,14 +577,15 @@
 ;;; Networking
 
 (defvar slime-net-process nil
-  "The process (socket) connected to CMUCL.")
+  "The process (socket) connected to the CL.")
 
 (defun slime-net-connect (host port)
-  "Establish a connection with CMUCL."
+  "Establish a connection with a CL."
   (condition-case nil
       (progn
-        (setq slime-net-process (open-network-stream "CMUCL" nil host port))
-        (let ((buffer (slime-make-net-buffer "*cmucl-connection*")))
+        (setq slime-net-process
+              (open-network-stream "SLIME Lisp" nil host port))
+        (let ((buffer (slime-make-net-buffer "*cl-connection*")))
           (set-process-buffer slime-net-process buffer)
           (set-process-filter slime-net-process 'slime-net-filter)
           (set-process-sentinel slime-net-process 'slime-net-sentinel)
@@ -609,7 +610,7 @@
   (slime-net-send `(,fun , at args)))
 
 (defun slime-net-send (sexp)
-  "Send a SEXP to CMUCL.
+  "Send a SEXP to inferior CL.
 This is the lowest level of communication. The sexp will be READ and
 EVAL'd by Lisp."
   (let* ((msg (format "%S\n" sexp))
@@ -1846,7 +1847,7 @@
   (if (null plists)
       (message "No apropos matches for %S" string)
     (save-current-buffer
-      (slime-with-output-to-temp-buffer "*CMUCL Apropos*"
+      (slime-with-output-to-temp-buffer "*SLIME Apropos*"
 	(set-buffer standard-output)
 	(apropos-mode)
 	(set-syntax-table lisp-mode-syntax-table)
@@ -476,7 +476,7 @@
 
 
-;;; CMUCL Setup: compiling and connecting to Swank
+;;; Inferior CL Setup: compiling and connecting to Swank
 
 (defvar slime-connect-retry-timer nil





More information about the slime-cvs mailing list